<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Namn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Användning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>Add New Application</source>
        <translation>Lägg Till Nytt Program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Add application</source>
        <translation>Lägg till program</translation>
    </message>
    <message>
        <source>Delete last added application</source>
        <translation type="vanished">Ta bort senast tillagda program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Border</source>
        <translation>Gräns</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>Select...</source>
        <translation>Välj...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Background</source>
        <translation>Bakgrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Back</source>
        <translation>Bakåt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Select icon...</source>
        <translation>Välj ikon...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Dock Preview</source>
        <translation>Förhandsvisning av Docka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="304"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Lägg till ett program i taget till dockan
2. Välj en .desktop-fil eller skriv in ett kommando för programmet du vill ha
3. Välj ikonegenskaper för storlek, bakgrund (svart är standard) och kant
4. Tryck på &quot;Lägg till program&quot; för att fortsätta eller &quot;Spara&quot; för att slutföra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>black</source>
        <translation>svart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>white</source>
        <translation>vit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Detta verktyg låter dig skapa en ny docka mett ett eller flera program. Du kan också redigera eller ta bort en tidigare skapad docka.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <source>Operation mode</source>
        <translation>Funktionssätt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Delete</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation type="vanished">&amp;Skapa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Dock name</source>
        <translation>Docknamn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="215"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Skriv in namnet som ska visas i Menyn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Select dock to delete</source>
        <translation>Välj docka att ta bort</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Confirmation</source>
        <translation>Bekräftelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Är du säker på att du vill ta bort %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Delete last application</source>
        <translation type="vanished">Ta bort senaste program</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Delete this application</source>
        <translation>Ta bort detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Overwrite?</source>
        <translation>Skriva över?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Vill du skriva över dockfilen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Save file</source>
        <translation>Spara fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Dock saved</source>
        <translation>Dockan sparad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Dockan har sparats.

För att redigera den nya dockan var vänlig välj &apos;Redigera en befintlig docka&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Description goes here</source>
        <translation>Plats för beskrivning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <source>Please select a file.</source>
        <translation type="vanished">Var vänlig välj en fil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Select .desktop file</source>
        <translation>Välj .desktop fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Skrivbordsfiler (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Select a dock file</source>
        <translation>Välj en dockfil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>No file selected</source>
        <translation>Ingen fil vald</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Du har inte valt en dockfil att redigera.
Skapar istället en ny docka.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open file</source>
        <translation>Kunde inte öppna fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Select dock to move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Kunde inte öppna vald fil.
Skapar istället en ny docka.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Redigera program ett i taget med Tillbaka och Nästa-knapparna
2. Lägg till eller ta bort program som du vill
3. När det är klart tryck på Spara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Select icon</source>
        <translation>Välj ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Ikoner (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Plats för Docka</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Överst Mitten</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Nedtill Vänster</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Nedtill Mitten</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Överst Vänster</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Överst Höger</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>Vänster Mitten</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>Höger Mitten</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Nedtill Höger</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>Höger Överst</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>Vänster Överst</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>Vänster Nedtill</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>Höger Nedtill</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Välj plats för docka</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as normal user.</source>
        <translation>Du måste köra det här programmet som vanlig användare.</translation>
    </message>
</context>
</TS>
